==> igniteui-angular-charts-14.1.1.tgz: package/esm5/lib/RadialAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { Array_$type, Point_$type, runOn, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { ViewportUtils } from "./ViewportUtils";
import { PropertyMetadata } from "igniteui-angular-core";
import { AnchoredRadialSeriesView } from "./AnchoredRadialSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var RadialAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialAreaSeries, _super);
    function RadialAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = RadialAreaSeries.$;
        return _this;
    }
    RadialAreaSeries.prototype.get_dd = function () {
        return true;
    };
    RadialAreaSeries.prototype.bx = function () {
        return new RadialAreaSeriesView(this);
    };
    RadialAreaSeries.prototype.lz = function (a) {
        _super.prototype.lz.call(this, a);
        this.t7 = a;
    };
    RadialAreaSeries.prototype.preferredCategoryMode = function (a) {
        return 0;
    };
    RadialAreaSeries.prototype.kx = function (a, b) {
        _super.prototype.kx.call(this, a, b);
        this.t7.c1();
    };
    RadialAreaSeries.prototype.sq = function (a, b) {
        _super.prototype.sq.call(this, a, b);
        var c = b.bv;
        var d = b.bu;
        var e = b;
        if (b.o() && !c.isEmpty && !d.isEmpty && this.rl != null && this.rs != null) {
            var f = a.f;
            var g = f.count;
            var h = new List$1(Array_$type, 2, g);
            var i = 0;
            for (var j = 0; j < g; j++) {
                var k = new Array(4);
                h.add(k);
                k[0] = this.rt.d(a.f._inner[j][0], a.f._inner[j][1], c, d);
                k[1] = this.rt.e(a.f._inner[j][0], a.f._inner[j][1], c, d);
                k[2] = this.rt.d(a.f._inner[j][0], a.f._inner[j][2], c, d);
                var l = a.f._inner[j][2];
                k[3] = this.rt.e(a.f._inner[j][0], l, c, d);
                if (l > i) {
                    i = l;
                }
            }
            var m = ViewportUtils.c(0.5, c, d);
            var n = ViewportUtils.f(0.5, c, d);
            this.t6 = { $type: Point_$type, x: m, y: n };
            var o = this.getEffectiveViewport1(e);
            this.rz.a0(this, this.sb(), runOn(this, this.ri), this.sd(b), this.se(b));
            var p = false;
            var q = this.rz.b;
            if (q != null) {
                p = true;
            }
            if (p) {
                var r = new ScalerParams(0, b.bv, b.bu, this.rl.cg, o);
                this.tp(f, -1, this.s4.count, this.rl, r, b.q);
            }
            var s = e.c9;
            var t = e.da;
            var u = e.c7;
            var v = e.c8;
            this.rz.ad(s, true, false, true, true);
            this.rz.ad(t, true, false, true, true);
            this.rz.ad(u, false, true, false, false);
            this.rz.ad(v, false, true, false, false);
            e.c2(a.f.count, h, false, this.t7.cs.b, this.ft, runOn(this, this.tq), this.t8);
            u._opacity = this.rz.j * this.fq;
            v._opacity = 0.5 * this.rz.j * this.fq;
        }
    };
    RadialAreaSeries.prototype.l4 = function (a, b, c, d) {
        _super.prototype.l4.call(this, a, b, c, d);
        switch (b) {
            case RadialAreaSeries.$$p[0]:
                this.mi(false);
                this.lp();
                break;
        }
    };
    RadialAreaSeries.prototype.get_s7 = function () {
        return true;
    };
    RadialAreaSeries.$t = markType(RadialAreaSeries, 'RadialAreaSeries', AnchoredRadialSeries.$);
    RadialAreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, RadialAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:t8:ua', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return RadialAreaSeries;
}(AnchoredRadialSeries));
export { RadialAreaSeries };
/**
 * @hidden
 */
var RadialAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialAreaSeriesView, _super);
    function RadialAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c0 = null;
        _this.c7 = new Path();
        _this.c9 = new Path();
        _this.c8 = new Path();
        _this.da = new Path();
        _this.c3 = new Path();
        _this.c5 = new Path();
        _this.c4 = new Path();
        _this.c6 = new Path();
        _this.c0 = a;
        return _this;
    }
    RadialAreaSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.c0.qd = Defaults.e;
        }
    };
    RadialAreaSeriesView.prototype.c1 = function () {
        this.c7.ak = null;
        this.c9.ak = null;
        this.c8.ak = null;
        this.da.ak = null;
        this.c3.ak = null;
        this.c5.ak = null;
        this.c4.ak = null;
        this.c6.ak = null;
        this.aq();
    };
    RadialAreaSeriesView.prototype.c2 = function (a, b, c, d, e, f, g) {
        this.cw.sz.i(this.c7, this.c9, this.c8, this.da, a, b, c, d, e, f, g);
        this.aq();
    };
    RadialAreaSeriesView.prototype.bb = function () {
        _super.prototype.bb.call(this);
    };
    RadialAreaSeriesView.prototype.bc = function () {
        _super.prototype.bc.call(this);
        var a = this.bo();
        this.c5.ak = this.c9.ak;
        this.c6.ak = this.da.ak;
        this.c3.ak = this.c7.ak;
        this.c4.ak = this.c8.ak;
        this.c5._stroke = a;
        this.c5.ac = this.e.fu + 3;
        this.c6._stroke = a;
        this.c6.ac = this.e.fu + 3;
        this.c3._fill = a;
        this.c3._opacity = 1;
        this.c4._fill = a;
        this.c4._opacity = 1;
    };
    RadialAreaSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.c3);
                a.s(this.c4);
                a.s(this.c5);
                a.s(this.c6);
            }
            else {
                a.s(this.c7);
                a.s(this.c8);
                a.s(this.c9);
                a.s(this.da);
            }
        }
    };
    RadialAreaSeriesView.prototype.al = function (a) {
        _super.prototype.al.call(this, a);
        this.e.a8.exportPathData(a, this.c9, "lowerShape", ["Lower"]);
        this.e.a8.exportPathData(a, this.da, "upperShape", ["Upper", "Main"]);
        this.e.a8.exportPathData(a, this.c8, "translucentShape", ["Translucent"]);
        this.e.a8.exportPathData(a, this.c7, "fillShape", ["Fill"]);
    };
    RadialAreaSeriesView.$t = markType(RadialAreaSeriesView, 'RadialAreaSeriesView', AnchoredRadialSeriesView.$);
    return RadialAreaSeriesView;
}(AnchoredRadialSeriesView));
export { RadialAreaSeriesView };

==> igniteui-angular-charts-14.2.0.tgz: package/esm5/lib/RadialAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { Array_$type, Point_$type, runOn, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { ViewportUtils } from "./ViewportUtils";
import { PropertyMetadata } from "igniteui-angular-core";
import { AnchoredRadialSeriesView } from "./AnchoredRadialSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var RadialAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialAreaSeries, _super);
    function RadialAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = RadialAreaSeries.$;
        return _this;
    }
    RadialAreaSeries.prototype.get_dd = function () {
        return true;
    };
    RadialAreaSeries.prototype.bx = function () {
        return new RadialAreaSeriesView(this);
    };
    RadialAreaSeries.prototype.l2 = function (a) {
        _super.prototype.l2.call(this, a);
        this.ub = a;
    };
    RadialAreaSeries.prototype.preferredCategoryMode = function (a) {
        return 0;
    };
    RadialAreaSeries.prototype.k0 = function (a, b) {
        _super.prototype.k0.call(this, a, b);
        this.ub.c1();
    };
    RadialAreaSeries.prototype.su = function (a, b) {
        _super.prototype.su.call(this, a, b);
        var c = b.bv;
        var d = b.bu;
        var e = b;
        if (b.o() && !c.isEmpty && !d.isEmpty && this.rp != null && this.rw != null) {
            var f = a.f;
            var g = f.count;
            var h = new List$1(Array_$type, 2, g);
            var i = 0;
            for (var j = 0; j < g; j++) {
                var k = new Array(4);
                h.add(k);
                k[0] = this.rx.d(a.f._inner[j][0], a.f._inner[j][1], c, d);
                k[1] = this.rx.e(a.f._inner[j][0], a.f._inner[j][1], c, d);
                k[2] = this.rx.d(a.f._inner[j][0], a.f._inner[j][2], c, d);
                var l = a.f._inner[j][2];
                k[3] = this.rx.e(a.f._inner[j][0], l, c, d);
                if (l > i) {
                    i = l;
                }
            }
            var m = ViewportUtils.c(0.5, c, d);
            var n = ViewportUtils.f(0.5, c, d);
            this.ua = { $type: Point_$type, x: m, y: n };
            var o = this.getEffectiveViewport1(e);
            this.r3.a0(this, this.sf(), runOn(this, this.rm), this.sh(b), this.si(b));
            var p = false;
            var q = this.r3.b;
            if (q != null) {
                p = true;
            }
            if (p) {
                var r = new ScalerParams(0, b.bv, b.bu, this.rp.cg, o);
                this.tt(f, -1, this.s8.count, this.rp, r, b.q);
            }
            var s = e.c9;
            var t = e.da;
            var u = e.c7;
            var v = e.c8;
            this.r3.ad(s, true, false, true, true);
            this.r3.ad(t, true, false, true, true);
            this.r3.ad(u, false, true, false, false);
            this.r3.ad(v, false, true, false, false);
            e.c2(a.f.count, h, false, this.ub.cs.b, this.fv, runOn(this, this.tu), this.uc);
            u._opacity = this.r3.j * this.fs;
            v._opacity = 0.5 * this.r3.j * this.fs;
        }
    };
    RadialAreaSeries.prototype.l7 = function (a, b, c, d) {
        _super.prototype.l7.call(this, a, b, c, d);
        switch (b) {
            case RadialAreaSeries.$$p[0]:
                this.ml(false);
                this.ls();
                break;
        }
    };
    RadialAreaSeries.prototype.get_tb = function () {
        return true;
    };
    RadialAreaSeries.$t = markType(RadialAreaSeries, 'RadialAreaSeries', AnchoredRadialSeries.$);
    RadialAreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, RadialAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:uc:ue', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return RadialAreaSeries;
}(AnchoredRadialSeries));
export { RadialAreaSeries };
/**
 * @hidden
 */
var RadialAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialAreaSeriesView, _super);
    function RadialAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c0 = null;
        _this.c7 = new Path();
        _this.c9 = new Path();
        _this.c8 = new Path();
        _this.da = new Path();
        _this.c3 = new Path();
        _this.c5 = new Path();
        _this.c4 = new Path();
        _this.c6 = new Path();
        _this.c0 = a;
        return _this;
    }
    RadialAreaSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.c0.qh = Defaults.e;
        }
    };
    RadialAreaSeriesView.prototype.c1 = function () {
        this.c7.ak = null;
        this.c9.ak = null;
        this.c8.ak = null;
        this.da.ak = null;
        this.c3.ak = null;
        this.c5.ak = null;
        this.c4.ak = null;
        this.c6.ak = null;
        this.aq();
    };
    RadialAreaSeriesView.prototype.c2 = function (a, b, c, d, e, f, g) {
        this.cw.s3.i(this.c7, this.c9, this.c8, this.da, a, b, c, d, e, f, g);
        this.aq();
    };
    RadialAreaSeriesView.prototype.bb = function () {
        _super.prototype.bb.call(this);
    };
    RadialAreaSeriesView.prototype.bc = function () {
        _super.prototype.bc.call(this);
        var a = this.bo();
        this.c5.ak = this.c9.ak;
        this.c6.ak = this.da.ak;
        this.c3.ak = this.c7.ak;
        this.c4.ak = this.c8.ak;
        this.c5._stroke = a;
        this.c5.ac = this.e.fw + 3;
        this.c6._stroke = a;
        this.c6.ac = this.e.fw + 3;
        this.c3._fill = a;
        this.c3._opacity = 1;
        this.c4._fill = a;
        this.c4._opacity = 1;
    };
    RadialAreaSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.c3);
                a.s(this.c4);
                a.s(this.c5);
                a.s(this.c6);
            }
            else {
                a.s(this.c7);
                a.s(this.c8);
                a.s(this.c9);
                a.s(this.da);
            }
        }
    };
    RadialAreaSeriesView.prototype.al = function (a) {
        _super.prototype.al.call(this, a);
        this.e.a8.exportPathData(a, this.c9, "lowerShape", ["Lower"]);
        this.e.a8.exportPathData(a, this.da, "upperShape", ["Upper", "Main"]);
        this.e.a8.exportPathData(a, this.c8, "translucentShape", ["Translucent"]);
        this.e.a8.exportPathData(a, this.c7, "fillShape", ["Fill"]);
    };
    RadialAreaSeriesView.$t = markType(RadialAreaSeriesView, 'RadialAreaSeriesView', AnchoredRadialSeriesView.$);
    return RadialAreaSeriesView;
}(AnchoredRadialSeriesView));
export { RadialAreaSeriesView };
